<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://ays-pro.com
 * @since             1.0.0
 * @package           Faq_Builder_Ays
 *
 * @wordpress-plugin
 * Plugin Name:       FAQ Builder
 * Plugin URI:        https://ays-pro.com
 * Description:       Installing FAQ shows how professional is your work and how attentive you are towards your customers, users, visitors
 * Version:           1.0.0
 * Author:            FAQ Builder Team
 * Author URI:        https://ays-pro.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       faq-builder-ays
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if( ! defined( 'AYS_FAQ_BASE_URL' ) ) {
    define( 'AYS_FAQ_BASE_URL', plugin_dir_url(__FILE__ ) );
}

if( ! defined( 'AYS_FAQ_DIR' ) )
    define( 'AYS_FAQ_DIR', plugin_dir_path( __FILE__ ) );

if( ! defined( 'AYS_FAQ_ADMIN_URL' ) ) {
    define( 'AYS_FAQ_ADMIN_URL', plugin_dir_url(__FILE__ ) . 'admin/' );
}

if( ! defined( 'AYS_FAQ_PUBLIC_URL' ) ) {
    define( 'AYS_FAQ_PUBLIC_URL', plugin_dir_url(__FILE__ ) . 'public/' );
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'FAQ_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-faq-builder-ays-activator.php
 */
function activate_faq_builder_ays() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-faq-builder-ays-activator.php';
	Faq_Builder_Ays_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-faq-builder-ays-deactivator.php
 */
function deactivate_faq_builder_ays() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-faq-builder-ays-deactivator.php';
	Faq_Builder_Ays_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_faq_builder_ays' );
register_deactivation_hook( __FILE__, 'deactivate_faq_builder_ays' );
add_action('plugins_loaded', 'activate_faq_builder_ays');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-faq-builder-ays.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_faq_builder_ays() {

	$plugin = new Faq_Builder_Ays();
	$plugin->run();

}
run_faq_builder_ays();
